# hattrick_libs

This is a library to transform xml-data from the API of the infamous online-strategy-game hattrick (https://www.hattrick.org) into python objects.

As this was just intended to be a python-learning-project and to be the ground-work for another hattrick-project of mine initially,
https://hattrick-fun-with-flags.app, hattick_libs doesn't aim to be complete nor useful to any other purpose than it was originally built for.

If you are looking for a complete python library for hattrick.org consider also pyCHPP by Pierre Gobin. His project was there before mine and 
looks quite sophisticated to me. It's implemented in an object-oriented style and thus well readable and clean. Compared to pyCHPP, hattrick_libs is a 
very basic implementation of the hattrick-API. But consider also this: If you are a learner like myself, hattrick_libs will be a perfect opportunity
to get your hands dirty on some cool python stuff without having to learn oop first. Or you decide to implement your own flavor of a hattick library 
in python and let yourself inspire by both this projects. There is room for all of us. Whatever your decision is: make sure to connect. Refer to the
"Contact" section of this document if you can help improve hattrick_libs, have suggestions, if you want to adopt it to your needs or if you just feel 
like having a chat with another nerdy hattrick manager.

Have fun!:)

## Project state
For now the projects state is experimental. It's just my this-year christmas project after all!;) I'm actively maintaining this project though.
(information as of 2023-12-30)

## Project link
https://github.com/joschobart/hattrick_libs

## Installation
```bash
pip3 install hattrick-libs 
```

## Usage
In your code directly reference to the module you need:
```python
from ht_libs import do_hattrick_request
```

## License
This package is licensed under the Apache License 2.0.

## Contact
joschobart on hattrick.org for a chat about bugs, hattrick, (monty) python or discworld.